pyriskadjust.hccs package
=========================

Submodules
----------

pyriskadjust.hccs.hccs\_v20 module
----------------------------------

.. automodule:: pyriskadjust.hccs.hccs_v20
    :members:
    :undoc-members:
    :show-inheritance:

pyriskadjust.hccs.hccs\_v22 module
----------------------------------

.. automodule:: pyriskadjust.hccs.hccs_v22
    :members:
    :undoc-members:
    :show-inheritance:

pyriskadjust.hccs.hccs\_v23 module
----------------------------------

.. automodule:: pyriskadjust.hccs.hccs_v23
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pyriskadjust.hccs
    :members:
    :undoc-members:
    :show-inheritance:
